(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     44709,       1053]
NotebookOptionsPosition[     41367,       1000]
NotebookOutlinePosition[     41787,       1017]
CellTagsIndexPosition[     41744,       1014]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"14bded44-54ab-40db-a902-732ee7da32aa"],

Cell["Chapter 8, Section 8.12.1, Figures 8.25\[Dash]26", "Section",
 CellChangeTimes->{{3.882006605439645*^9, 
  3.8820066110954123`*^9}},ExpressionUUID->"82f499f7-7566-4202-8352-\
b2938cf7819e"],

Cell[TextData[{
 "The definitions of the following functions are taken from the PhD thesis of \
Malhotra (1988).\n\nWe consider first-order resonances and define the \
functions ",
 StyleBox["\[Psi]", "Input"],
 ", ",
 StyleBox["\[CapitalPhi]1", "Input"],
 ", ",
 StyleBox["\[CapitalPhi]2", "Input"],
 ", ",
 StyleBox["\[CapitalPhi]3", "Input"],
 ", ",
 StyleBox["\[CapitalPhi]min", "Input"],
 ", ",
 StyleBox["\[CapitalPhi]max", "Input"],
 " and ",
 StyleBox["\[Gamma]", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.882007175802137*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8934e077-7d45-47ea-b3df-ccb2b93927ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Psi]", "[", "\[Delta]_", "]"}], " ", ":=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"ArcTan", "[", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Delta]", "+", "1"}], ")"}], "^", "3"}], "-", "1"}], "]"}],
      "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8820054478928022`*^9, 3.882005447900728*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"a20848e7-2917-4152-827b-9f1f38520833"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPhi]1", "[", "\[Delta]_", "]"}], " ", ":=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"2", "*", 
     RowBox[{"(", 
      RowBox[{"\[Delta]", "+", "1"}], ")"}], "*", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"\[Psi]", "[", "\[Delta]", "]"}], "/", "3"}], "]"}], "^", 
      "2"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.882005458519723*^9, 3.882005458526002*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"6470a898-2607-4ca4-a5e2-90a9ea1689f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPhi]2", "[", "\[Delta]_", "]"}], " ", ":=", " ", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"\[Delta]", "+", "1"}], ")"}], "*", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"\[Psi]", "[", "\[Delta]", "]"}], "/", "3"}], "]"}], "-", 
        RowBox[{
         RowBox[{"Sqrt", "[", "3", "]"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"\[Psi]", "[", "\[Delta]", "]"}], "/", "3"}], "]"}]}]}], 
       ")"}], "^", "2"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.882005467791986*^9, 3.882005467797777*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"84f92719-4099-477c-9a5a-ddb0e5ec0d37"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPhi]3", "[", "\[Delta]_", "]"}], " ", ":=", " ", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"\[Delta]", "+", "1"}], ")"}], "*", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"\[Psi]", "[", "\[Delta]", "]"}], "/", "3"}], "]"}], "+", 
        RowBox[{
         RowBox[{"Sqrt", "[", "3", "]"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"\[Psi]", "[", "\[Delta]", "]"}], "/", "3"}], "]"}]}]}], 
       ")"}], "^", "2"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.882005476711451*^9, 3.882005476717938*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"4fce5ca1-4d5e-4d35-8f67-7bc761f8aa6f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPhi]min", "[", "\[Delta]_", "]"}], " ", ":=", " ", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{"\[Delta]", "+", "1"}], ")"}]}], " ", "-", " ", 
     RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}], " ", "-", " ", 
     RowBox[{"2", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "*", 
         RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}]}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "4"}], ")"}]}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8820054860800133`*^9, 3.8820054860861597`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"ad5e84ac-e42f-44a0-8f77-62ea27eb6156"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPhi]max", "[", "\[Delta]_", "]"}], " ", ":=", " ", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{"\[Delta]", "+", "1"}], ")"}]}], " ", "-", " ", 
     RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}], " ", "+", " ", 
     RowBox[{"2", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "*", 
         RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}]}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "4"}], ")"}]}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.882005494940781*^9, 3.8820054949474373`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"efbf6ac8-abf3-4324-8a2f-84a15031bdfc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "\[Delta]_", "]"}], " ", ":=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"ArcSin", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[CapitalPhi]max", "[", "\[Delta]", "]"}], "+", 
        RowBox[{"\[CapitalPhi]min", "[", "\[Delta]", "]"}], "-", 
        RowBox[{"2", "*", 
         RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[CapitalPhi]max", "[", "\[Delta]", "]"}], "-", 
        RowBox[{"\[CapitalPhi]min", "[", "\[Delta]", "]"}]}], ")"}]}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.882005504137642*^9, 3.882005507233046*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"db1d5eca-2e84-4334-a7fa-247b64d70e27"],

Cell["\<\
Now define the functions to calculate the area enclosed by the outer and \
inner branches of the separatrix (see Eqs.(8.213) and (8.214).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c5f0a791-4435-4e4d-b383-64b64e48b691"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Areaext", "[", "\[Delta]_", "]"}], " ", ":=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"Abs", "[", "\n", 
     RowBox[{
      RowBox[{"-", "3"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalPhi]max", "[", "\[Delta]", "]"}], " ", "+", " ", 
           
           RowBox[{"\[CapitalPhi]min", "[", "\[Delta]", "]"}], " ", "+", " ", 
           
           RowBox[{"2", "*", 
            RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}]}], " ", "-", " ", 
           RowBox[{"2", "*", 
            RowBox[{"(", 
             RowBox[{"\[Delta]", "+", "1"}], ")"}]}]}], ")"}], "*", "\n", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Pi", "/", "2"}], "+", 
           RowBox[{"\[Gamma]", "[", "\[Delta]", "]"}]}], ")"}]}], " ", "+", 
        " ", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalPhi]max", "[", "\[Delta]", "]"}], "-", 
            RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}], "-", 
            RowBox[{"\[CapitalPhi]min", "[", "\[Delta]", "]"}]}], ")"}]}], 
         "]"}]}], ")"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.882005540607718*^9, 3.88200554061383*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"3ba026ae-9e9b-4a3d-af73-df3334d6cfbf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Areaint", "[", "\[Delta]_", "]"}], " ", ":=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"Abs", "[", "\n", 
     RowBox[{"3", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalPhi]max", "[", "\[Delta]", "]"}], " ", "+", " ", 
           
           RowBox[{"\[CapitalPhi]min", "[", "\[Delta]", "]"}], " ", "+", " ", 
           
           RowBox[{"2", "*", 
            RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}]}], " ", "-", " ", 
           RowBox[{"2", "*", 
            RowBox[{"(", 
             RowBox[{"\[Delta]", "+", "1"}], ")"}]}]}], ")"}], "*", "\n", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Pi", "/", "2"}], "-", 
           RowBox[{"\[Gamma]", "[", "\[Delta]", "]"}]}], ")"}]}], " ", "-", 
        " ", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalPhi]max", "[", "\[Delta]", "]"}], "-", 
            RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[CapitalPhi]3", "[", "\[Delta]", "]"}], "-", 
            RowBox[{"\[CapitalPhi]min", "[", "\[Delta]", "]"}]}], ")"}]}], 
         "]"}]}], ")"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.88200555056734*^9, 3.8820055505731983`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"02bdd4a0-e432-4431-be4f-aeb03cedf5a3"],

Cell["\<\
Define the function that gives the probability of capture (see Eq.(8.220)).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fbeac890-c26d-4b9f-af6d-86d66f18bbd0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ProbCap", "[", "\[Delta]_", "]"}], " ", ":=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"4", "*", 
     RowBox[{
      RowBox[{"\[Gamma]", "[", "\[Delta]", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"Pi", "+", 
        RowBox[{"2", "*", 
         RowBox[{"\[Gamma]", "[", "\[Delta]", "]"}]}]}], ")"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.882005567356585*^9, 3.882005567363138*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"1e70c9dc-a64a-4a50-b50e-065a5b6f7ca0"],

Cell["Define the axis labels.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4622826f-99c2-4c0a-bdfe-37381235644f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SubscriptBox[\"\[Delta]\", \"t\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\delta_{\\\\rm{t}}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel1", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
FractionBox[
StyleBox[\"A\", \"TI\"], 
RowBox[{\"2\", \"\[Pi]\"}]], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"{{A}\\\\over{2\\\\pi}}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel2", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SubscriptBox[
StyleBox[\"P\", \"TI\"], \"cap\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"P_{\\\\rm{cap}}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.880100664379323*^9, 3.880100667376337*^9}, {
   3.881480907052763*^9, 3.881480910113048*^9}, 3.882005997664741*^9, {
   3.8820060337864847`*^9, 3.8820060757749453`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"791345f6-0ce9-4e74-9a63-e642e7f7c91f"],

Cell["\<\
Plot the area enclosed by the outer branch of the separatrix.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e532aa9a-f04e-433c-baba-f10c60db6389"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"outer1", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Areaext", "[", "\[Delta]", "]"}], "/", "2"}], "/", "Pi"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Delta]", ",", "0", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8820055834765177`*^9, 3.8820055834824667`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"6dc0af44-551f-4ded-9477-276c5652bf36"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV0Hk4lAkAx/FpJzXrPsqRY45XM4xzvFGWvD+m3XJuQj10MUKra2tNrGPJ
0ZgcTaUcrZWzbVs6lopKVnKnotUxbEW2qBSadVW2/eP7fP7/skV71oV9QaPR
vD/3v4U/iRYItmW40EMjfGk0Bpp6WF4bWN9RDRy69ogmA3PN9Sks1o/UqxY9
NyabgcKGLKYSS0oxGVeF+WBg50rxrklmPtX6S7tvWAIDPbPbc94xz1AavyUa
GI8zsFA+wHvDrKW2ChamNN79EsXtRXtfMdso96dWjJH9Kqg6J5XvtH5MFW+6
ODp0Xx0R1L381/sGqfQDafrdI5rYPWQ+WF01TJnJd9W7BmpDmZ3Ke7LiHcWQ
rVXK+lsH2Zod/OLgCWqsZ6xfZdViiOT+N+id/1LIzr2S0KiLvbdSRXt4M1Qy
EZzRb6+PC9+r+um7f6QmjCfeO2UZoDhux4jtBhrCuLkuNz4tQXLRB9/3r+fh
LJUZFBlgBFrPU1yLpWO2P3jT/lJjcKPCY/z5SmiTX6hTVmXiuSJ3vcr1BdgT
ovCPtmLBYygy4eheBp75rBbaD7Dg81xmYWKijGcLM5vGj7IxclOU1Fqpgpkf
Tqc5LOfAWqvXWLhVDdK55o93XnKgTClC+ibUkfqpTk0/m8DqN0GTnABNyOnu
x/6AKR42bpsXZKmFW+XC2fy3pqhJb9rCUmjBYlQuCz26FOFK4qddXdqou9vp
k+TGRei+uBrVAh382rnCIe8fLmwiLLq8Qhbhar5NpoWEhzvalipix8VwOr4t
UMPeDFerkk9a0nXx8pHelPoDM8TN46/t7NdFFcl1DTpoDuW+2DW7q/WgVVH/
jZUdH0MV7JyieH2MNgT+7NDNR46ZwfzaAANIDwWfkiRaQFYQ3hLCWgIZIT1v
yLZEUM7mLtUXS0DLvbTU94YlplaVTxfVG8Ja/eWi9kgrDA65xTRKjMAW613O
U7ZGyUqB4e0QY9jLfCIrLlujMk2sFWFlgjJvqVAn0AaSgFBPusIENW+nUmwm
bWDfV3xGcpsJrRLeFqGvLfLMT1be9mQhxVyzcmmxLRIbsvI8a1n4PYedUDpp
C2/DgPJ2UzbqENMd6yWA6+6WjVpSNrqa/Q0PnxSgyEhk2qlgQ+a/ftx5TADT
m6dP+GzkIFz+/hHf1Q4yq0Z+dz0HdToDkpjDdgifmH+vjU8g8/iy0c3P7SC6
MM6SHiZQa+O0Kp0ksTPZ74PHEQKOeaZlw8tIiP2qH6geI0ATadA9HUikK8TZ
shME3lYOX1dzJFHlOD2bW0gg176Gd8yFxPSfc70VZwnkB7V2FLqTkHWrZjW1
ELg8/mT9xa0kCkp3bT/YRsC03zlXJ4REaVSXcE0HgejrRb1RIhKXdGUzHV0E
nN9Fr1seRqIvSGd7z18EPDT2u1yLJMEbNBAODBLYeKr1xS0xCdvqWJOyIQLf
Nh3X50WT+CpNPh32goC60Y416TEkvHiF54dHCHytsC73iCOxbwfLZGyMQJSA
6XcniUS884HpixMErvQK4m2TSaSpDdyPUhCo6/AuO5JCIu9cacbUFAGuXcmY
30ESJUnzI+pmPv8ZeaxbIyFx1jfMLf4DAYtEYyddKYlqTrOxyycCyxdFbok+
RKJ+gjs9N0egoLMh6WEGif8AobUUSQ==
       "]]},
     Annotation[#, "Charting`Private`Tag$3873#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 3.000000606505986},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {3.000000606505979, 19.5462723227216}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.882005584823037*^9, 3.882007812651987*^9, 3.882035238123949*^9, 
   3.882035358974053*^9, 3.882035395200275*^9, 3.8820354550102043`*^9, {
   3.8909809932545557`*^9, 3.8909810073282747`*^9}, 3.8909811584930477`*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"9fb97933-abd0-44be-8a5f-428ce975442b"]
}, Open  ]],

Cell["\<\
Plot the area enclosed by the inner branch of the separatrix.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5375ca84-0d63-4040-a26d-e55cc7a56e3c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"inner1", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Areaint", "[", "\[Delta]", "]"}], "/", "2"}], "/", "Pi"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Delta]", ",", "0", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.882005608954071*^9, 3.882005608960182*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"2b42f6b6-aab5-4cf1-a36e-88bd80155635"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVyX881IcfwPE7p+E4c8UVuXN3H1w+rLEfPbTv9H47vjHM1ko1t2UuOVto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       "]]},
     Annotation[#, "Charting`Private`Tag$4066#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0., 13.453727065033496`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.882005609442567*^9, 3.882007812755588*^9, 3.882035238261314*^9, 
   3.882035359114974*^9, 3.882035395367569*^9, 3.882035455142548*^9, {
   3.890980993386923*^9, 3.8909810074502373`*^9}, 3.890981158639792*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"1d00ed96-65d4-4496-8780-667ef211dbbc"]
}, Open  ]],

Cell["Define the inner and outer labels.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}, {
  3.882035428931944*^9, 3.882035434667725*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6554979a-b501-4a9f-9a83-ac5e4bdfc9e9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"innerlabel", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<inner\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"6", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outerlabel", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<outer\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"3.8", ",", "13"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.882035058818726*^9, 3.882035208024719*^9}, {
  3.882035273944602*^9, 3.882035324430416*^9}, {3.8820353688314533`*^9, 
  3.8820353720935287`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"ca09e3e9-993b-42d7-bd66-dbb8cb303565"],

Cell["Show both plots together.  This is Fig.8.25.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8820066970138483`*^9, 3.882006716260282*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"48568bd2-666b-49e8-b89a-0e9985eac480"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areas1", " ", "=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{"outer1", ",", "inner1", ",", "innerlabel", ",", "outerlabel", ",", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", "\n", "     ", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "20"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", 
       RowBox[{"Rotate", "[", 
        RowBox[{"ylabel1", ",", 
         RowBox[{
          RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.882005627770591*^9, 3.88200562777664*^9}, {
  3.882006118687484*^9, 3.882006154649267*^9}, {3.882035224168639*^9, 
  3.8820352343680487`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"5befbb9c-4447-4287-92d4-83af1c008426"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0Hk4lAkAx/FpJzXrPsqRY45XM4xzvFGWvD+m3XJuQj10MUKra2tNrGPJ
0ZgcTaUcrZWzbVs6lopKVnKnotUxbEW2qBSadVW2/eP7fP7/skV71oV9QaPR
vD/3v4U/iRYItmW40EMjfGk0Bpp6WF4bWN9RDRy69ogmA3PN9Sks1o/UqxY9
NyabgcKGLKYSS0oxGVeF+WBg50rxrklmPtX6S7tvWAIDPbPbc94xz1AavyUa
GI8zsFA+wHvDrKW2ChamNN79EsXtRXtfMdso96dWjJH9Kqg6J5XvtH5MFW+6
ODp0Xx0R1L381/sGqfQDafrdI5rYPWQ+WF01TJnJd9W7BmpDmZ3Ke7LiHcWQ
rVXK+lsH2Zod/OLgCWqsZ6xfZdViiOT+N+id/1LIzr2S0KiLvbdSRXt4M1Qy
EZzRb6+PC9+r+um7f6QmjCfeO2UZoDhux4jtBhrCuLkuNz4tQXLRB9/3r+fh
LJUZFBlgBFrPU1yLpWO2P3jT/lJjcKPCY/z5SmiTX6hTVmXiuSJ3vcr1BdgT
ovCPtmLBYygy4eheBp75rBbaD7Dg81xmYWKijGcLM5vGj7IxclOU1Fqpgpkf
Tqc5LOfAWqvXWLhVDdK55o93XnKgTClC+ibUkfqpTk0/m8DqN0GTnABNyOnu
x/6AKR42bpsXZKmFW+XC2fy3pqhJb9rCUmjBYlQuCz26FOFK4qddXdqou9vp
k+TGRei+uBrVAh382rnCIe8fLmwiLLq8Qhbhar5NpoWEhzvalipix8VwOr4t
UMPeDFerkk9a0nXx8pHelPoDM8TN46/t7NdFFcl1DTpoDuW+2DW7q/WgVVH/
jZUdH0MV7JyieH2MNgT+7NDNR46ZwfzaAANIDwWfkiRaQFYQ3hLCWgIZIT1v
yLZEUM7mLtUXS0DLvbTU94YlplaVTxfVG8Ja/eWi9kgrDA65xTRKjMAW613O
U7ZGyUqB4e0QY9jLfCIrLlujMk2sFWFlgjJvqVAn0AaSgFBPusIENW+nUmwm
bWDfV3xGcpsJrRLeFqGvLfLMT1be9mQhxVyzcmmxLRIbsvI8a1n4PYedUDpp
C2/DgPJ2UzbqENMd6yWA6+6WjVpSNrqa/Q0PnxSgyEhk2qlgQ+a/ftx5TADT
m6dP+GzkIFz+/hHf1Q4yq0Z+dz0HdToDkpjDdgifmH+vjU8g8/iy0c3P7SC6
MM6SHiZQa+O0Kp0ksTPZ74PHEQKOeaZlw8tIiP2qH6geI0ATadA9HUikK8TZ
shME3lYOX1dzJFHlOD2bW0gg176Gd8yFxPSfc70VZwnkB7V2FLqTkHWrZjW1
ELg8/mT9xa0kCkp3bT/YRsC03zlXJ4REaVSXcE0HgejrRb1RIhKXdGUzHV0E
nN9Fr1seRqIvSGd7z18EPDT2u1yLJMEbNBAODBLYeKr1xS0xCdvqWJOyIQLf
Nh3X50WT+CpNPh32goC60Y416TEkvHiF54dHCHytsC73iCOxbwfLZGyMQJSA
6XcniUS884HpixMErvQK4m2TSaSpDdyPUhCo6/AuO5JCIu9cacbUFAGuXcmY
30ESJUnzI+pmPv8ZeaxbIyFx1jfMLf4DAYtEYyddKYlqTrOxyycCyxdFbok+
RKJ+gjs9N0egoLMh6WEGif8AobUUSQ==
        "]]},
      Annotation[#, "Charting`Private`Tag$3873#1"]& ]}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVyX881IcfwPE7p+E4c8UVuXN3H1w+rLEfPbTv9H47vjHM1ko1t2UuOVto
eWQhFVbp1uT8+MqPZJcfX5ro6lQnIj+SH1GUa9H8uDwUmfy4dDc/vvv+8Xo8
/3jxxAe+2mdAoVDE//R/C4+J33ELO7Olt0XJNChz39LSxw3Yxf0eDkx+G7Iw
Gggrd2//zOXGg8Py7hu1XmIwz7x+hf4kBdSn+KcC3KKhsDHNbhVXCqzPhD7n
0mLBZTrs7IokHZw/ivjCLDwRnplfWF5UZ0L6URNa+b1kiPSIjVqwy4O1Fdy7
CcFSuPZouGTe6zx802XvwfoiDfT7AwZnJEWg7oob+KVKBt73MxzeqC/C0YYC
VuKf2dD3d0T2a7sKMBz6rZalKISf2jiu04pLsOF5ffJOfRHYZD3qnPKqBNrY
YFy8gxzEJNImJdXwIqtnQ1RSMcRVmqpm1VeBXZ3zpFBUDkYDo4IpOxXw9zWx
Dvso4EljfeyrFyoYOb5pQTWtgEtluc2TilpY41WYSsm7CoExgSETXnWgYu1p
TvzrGuSY1OaMSxpgx3Cra3LJdVh9/p7BjLoJ7hWry23c60DeUXRw0q4dgkXU
Xt5MM8zn1pBDv7ZDRph+ifp1C2yVdGp6de3gccZZ5XanBV7RFoJq+zpgsYJ6
LSGzFdw9Aj+RpnbBQGVpucy9DR5ULxoIpnsgacGiTZ3RAcc7XPzcQvqgPb+5
S6h6AFXV0oHIjU+BQtLZa5+rQQIP817FaGBe4WPysYEGosecNMqql0BVm1+3
EE4AnXdCMOT+GgwJv9DvXWfgrEUnKf9uDoZG8oyVTC2IB3Y00LregPPXv4ks
g3VwsPWE+IBAD1ubGHr1hSVQ/Gi2fd1nS2AXVZnp0kdB+ZH9E667KMhxtBRa
GtMwpWhx2/wrKm4OeYbGtquQ0jeMdQk0pNcPm/g6GaHjofC4HeQqHCnpmRsP
N8Hn2nM7TevfwSnRbLV3sin6jf1wNPOgMYoPEftHOxkY+FzmzOHQ8cpWz5s+
RhY40SxOunfZFKc9/l0DLCZuZPazvUIYWGPzocLbYzXSQRs6OGeO0pH4w/nb
1qDPVPACP8gC2Y3HGqjHLPFJUxg12IWJS4tljKelVlhzumUPV8vErvr/6PNq
WRi+Kna4u3s11kW30iLH1+LemCM1ZvlrsL+eotRSrPF9iXN3QKglWhkQX6Vb
2WDPahfT2M1WqGXcikbherxVlVLgQmPhnt27RyUiWzxCJb/sesZCi0K36Cu/
spE+mOAbrVyLKz5z/q9vcnCsjJddlLgO+2MUPx98aIfZG6wNVUHWGPRB6xgj
mYuy/PC2UK4N+rbI9D+9y8Pg7G+7zcZtUNr2+F1hAQ/fepfqim6vx61/pI84
fMhHzZgwrinVFms0AUv0O3y86OG2/n4oGz0DjmxhiAi8fDKWKXmPg8/0ZTuN
JglMDdrrT9NyMN/CNioozh4/HpRXpN63w42niKYWpgPmOhVcvu/PxTtOiiq2
3AGPN6bl+qu4SKwL7yn41BE/Xx9U2mHPw8MPzP1/eOyIntFtIqaUh071lYNW
YQIsshXbd2l5WFcZf3piWYD2zf/NCRTx8UImwyInfQPK3msie2/z0SM05ceT
bCcMnzN82E4SaF1dmiO/4YRixSxXmk7gDWXo0198SIxM2b7ol0Fg705FJcOP
xNjtSrVZFoHfbVpOkgWQeFobe1aWQ+CtE2ffz9lGYtVm3d/nCgl86plcIheR
qLuz0l/2+z9fFj118wCJsl6ztJY2AoWZ4boX50jML46KONVOoNS1hx6ZT2Lx
oW4v304C3446c6bPk3idJdN3dhNYvrfRTysncTB4TUTfYwINZj+/Ra0kUaCx
9hrVEFgXUaezaSTRVZnAKRkjcDbLm7zQROInJwd0+8YJzNpV9w2vlcQAQeGV
lxMEBp+JbxN0kBizn8uZmSEwZoiv/OgRiYmfJuuuzhFoaMydv9FP4knG6KND
WgI5GfRN//qDxNzq4jNv3xKYeKmswfNPEi8mGUpq9QQevrzLqHWYxN+37RMm
LhJY8Wb+S18NiUr+XfaWZQKr4dj5zjESb8856lZWCKQJ514GviDxf5OxzaI=

        "]]},
      Annotation[#, "Charting`Private`Tag$4066#1"]& ]}, {}}, 
   StyleBox[
    InsetBox["\<\"inner\"\>", {6, 5}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]],
    FontFamily->"Times",
    FontSize->16], 
   StyleBox[
    InsetBox["\<\"outer\"\>", {3.8, 13}, NCache[
     ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]],
    FontFamily->"Times",
    FontSize->16]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[SubscriptBox[\\\"\
\[Delta]\\\", \\\"t\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\
\" -> \\\"\\\\\\\\delta_{\\\\\\\\rm{t}}\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], 
    FormBox[
     RotationBox[
     "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[FractionBox[StyleBox[\
\\\"A\\\", \\\"TI\\\"], RowBox[{\\\"2\\\", \\\"\[Pi]\\\"}]], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"{{A}\\\\\\\\over{2\\\\\\\\pi}}\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
      BoxRotation -> -1.5707963267948966`], TraditionalForm]},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10}, {0, 20}},
  PlotRangeClipping->True,
  PlotRangePadding->None,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.882005629131287*^9, {3.8820061334604187`*^9, 3.8820061563111467`*^9}, 
   3.882006225459004*^9, {3.882006422798691*^9, 3.882006437961031*^9}, 
   3.882007812774185*^9, 3.882035238378409*^9, 3.8820352785513906`*^9, 
   3.882035327109676*^9, {3.8820353591919127`*^9, 3.8820353954442053`*^9}, 
   3.8820354551885242`*^9, {3.89098099342163*^9, 3.89098100774751*^9}, 
   3.8909811589513073`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"b9a50f81-018c-471e-8ee0-a426559cfc62"]
}, Open  ]],

Cell[TextData[{
 "Now do the plot of probability of capture as a function of the value of \
\[Delta] at transition, ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       SubscriptBox["\[Delta]", "t"], TraditionalForm], "errors" -> {}, 
     "input" -> "\\delta_{\\rm{t}}", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "e3da8361-9226-4add-b65f-d352cc6115cf"],
 ".   This is Fig.8.26."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.882006727189437*^9, 3.882006758022135*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"61db3787-bd9a-42a6-844e-446de2700174"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prob1", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"ProbCap", "[", "\[Delta]", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Delta]", ",", "0", ",", "10"}], "}"}], ",", "\n", "  ", 
    RowBox[{"Frame", "->", "True"}], ",", "\n", "  ", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", "\n", "     ", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", 
       RowBox[{"Rotate", "[", 
        RowBox[{"ylabel2", ",", 
         RowBox[{
          RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8820056485130653`*^9, 3.882005648519039*^9}, {
  3.8820064734463587`*^9, 3.8820064927791157`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"a5d816da-41d7-4546-ad8c-57e04e760f10"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVkmk41IsCh20de4mTJPtgSo7ktgq/v+QodbrKkiQiGSJbqSyVkuSkklRa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       "]]},
     Annotation[#, "Charting`Private`Tag$4130#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SubscriptBox[StyleBox[\\\"P\\\", \\\"TI\\\"], \\\"cap\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"P_{\\\\\\\\rm{cap}}\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[SubscriptBox[\\\"\
\[Delta]\\\", \\\"t\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\
\" -> \\\"\\\\\\\\delta_{\\\\\\\\rm{t}}\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 10.}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.882005649883564*^9, 3.882006493955077*^9, 3.882007812862005*^9, 
   3.882035238516924*^9, 3.882035359307445*^9, 3.882035395574257*^9, 
   3.882035455293467*^9, {3.8909809935194597`*^9, 3.89098100786058*^9}, 
   3.89098115907268*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"3cac4752-d2bc-4337-a1c7-cef62995f85b"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1047, 663},
WindowMargins->{{83, Automatic}, {Automatic, 26}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"a44f014b-5947-4915-b1e6-4140f483b1a8"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"14bded44-54ab-40db-a902-732ee7da32aa"],
Cell[1000, 31, 195, 3, 67, "Section",ExpressionUUID->"82f499f7-7566-4202-8352-b2938cf7819e"],
Cell[1198, 36, 650, 22, 95, "Text",ExpressionUUID->"8934e077-7d45-47ea-b3df-ccb2b93927ad"],
Cell[1851, 60, 491, 13, 30, "Input",ExpressionUUID->"a20848e7-2917-4152-827b-9f1f38520833"],
Cell[2345, 75, 537, 14, 30, "Input",ExpressionUUID->"6470a898-2607-4ca4-a5e2-90a9ea1689f8"],
Cell[2885, 91, 836, 23, 30, "Input",ExpressionUUID->"84f92719-4099-477c-9a5a-ddb0e5ec0d37"],
Cell[3724, 116, 836, 23, 30, "Input",ExpressionUUID->"4fce5ca1-4d5e-4d35-8f67-7bc761f8aa6f"],
Cell[4563, 141, 723, 18, 30, "Input",ExpressionUUID->"ad5e84ac-e42f-44a0-8f77-62ea27eb6156"],
Cell[5289, 161, 721, 18, 30, "Input",ExpressionUUID->"efbf6ac8-abf3-4324-8a2f-84a15031bdfc"],
Cell[6013, 181, 789, 19, 30, "Input",ExpressionUUID->"db1d5eca-2e84-4334-a7fa-247b64d70e27"],
Cell[6805, 202, 271, 6, 53, "Text",ExpressionUUID->"c5f0a791-4435-4e4d-b383-64b64e48b691"],
Cell[7079, 210, 1592, 41, 73, "Input",ExpressionUUID->"3ba026ae-9e9b-4a3d-af73-df3334d6cfbf"],
Cell[8674, 253, 1567, 40, 73, "Input",ExpressionUUID->"02bdd4a0-e432-4431-be4f-aeb03cedf5a3"],
Cell[10244, 295, 209, 5, 53, "Text",ExpressionUUID->"fbeac890-c26d-4b9f-af6d-86d66f18bbd0"],
Cell[10456, 302, 529, 14, 30, "Input",ExpressionUUID->"1e70c9dc-a64a-4a50-b50e-065a5b6f7ca0"],
Cell[10988, 318, 656, 10, 53, "Text",ExpressionUUID->"4622826f-99c2-4c0a-bdfe-37381235644f"],
Cell[11647, 330, 1189, 24, 97, "Input",ExpressionUUID->"791345f6-0ce9-4e74-9a63-e642e7f7c91f"],
Cell[12839, 356, 195, 5, 53, "Text",ExpressionUUID->"e532aa9a-f04e-433c-baba-f10c60db6389"],
Cell[CellGroupData[{
Cell[13059, 365, 434, 10, 30, "Input",ExpressionUUID->"6dc0af44-551f-4ded-9477-276c5652bf36"],
Cell[13496, 377, 3646, 78, 241, "Output",ExpressionUUID->"9fb97933-abd0-44be-8a5f-428ce975442b"]
}, Open  ]],
Cell[17157, 458, 195, 5, 53, "Text",ExpressionUUID->"5375ca84-0d63-4040-a26d-e55cc7a56e3c"],
Cell[CellGroupData[{
Cell[17377, 467, 430, 10, 30, "Input",ExpressionUUID->"2b42f6b6-aab5-4cf1-a36e-88bd80155635"],
Cell[17810, 479, 4068, 86, 244, "Output",ExpressionUUID->"1d00ed96-65d4-4496-8780-667ef211dbbc"]
}, Open  ]],
Cell[21893, 568, 716, 11, 53, "Text",ExpressionUUID->"6554979a-b501-4a9f-9a83-ac5e4bdfc9e9"],
Cell[22612, 581, 1253, 34, 52, "Input",ExpressionUUID->"ca09e3e9-993b-42d7-bd66-dbb8cb303565"],
Cell[23868, 617, 238, 4, 53, "Text",ExpressionUUID->"48568bd2-666b-49e8-b89a-0e9985eac480"],
Cell[CellGroupData[{
Cell[24131, 625, 1409, 34, 73, "Input",ExpressionUUID->"5befbb9c-4447-4287-92d4-83af1c008426"],
Cell[25543, 661, 7146, 143, 252, "Output",ExpressionUUID->"b9a50f81-018c-471e-8ee0-a426559cfc62"]
}, Open  ]],
Cell[32704, 807, 633, 15, 55, "Text",ExpressionUUID->"61db3787-bd9a-42a6-844e-446de2700174"],
Cell[CellGroupData[{
Cell[33362, 826, 1706, 44, 115, "Input",ExpressionUUID->"a5d816da-41d7-4546-ad8c-57e04e760f10"],
Cell[35071, 872, 6280, 125, 248, "Output",ExpressionUUID->"3cac4752-d2bc-4337-a1c7-cef62995f85b"]
}, Open  ]]
}
]
*)

